declare('customhud', {})

customhud.event={}
customhud.updateevent={}
customhud.timer={}
customhud.ammoweapons={}

customhud.doupdate=false

dofile('vars.lua')
dofile('func.lua')
dofile('ui.lua')
dofile('uiconfig.lua')

customhud.timer.refresh=Timer()
function customhud.refresh()
	if customhud.doupdate then
	customhud.update()
	customhud.timer.refresh:SetTimeout(customhud.vars.refreshdelay, function() customhud.refresh() end)
	end
end

function customhud.pauserefresh()
	if customhud.doupdate then
		customhud.doupdate=false
	end
end

function customhud.resumerefresh()
	if not customhud.doupdate then
		customhud.doupdate=true
		customhud.refresh()
	end
end

function customhud.update()
	local name,health,dist,factionid,guild,ship=GetTargetInfo()
	if dist then
		customhud.ui.targetdistance.title=math.floor(dist)..'m'
	else 
		customhud.ui.targetdistance.title=nil
	end
end

function customhud.updatetargetname()
	local name,health,dist,factionid,guild,ship=GetTargetInfo()
	if guild~=nil and guild~='' then
		customhud.ui.targetname.title='[' .. guild .. ']' .. ' ' .. name
	else
		customhud.ui.targetname.title=name
	end

	customhud.ui.targetship.title=(ship or nil)
end

function customhud.updatetargethealth()
	local name,health,dist,factionid,guild,ship,shields=GetTargetInfo()
	if health then
		health=tostring(health*100)
		customhud.ui.targethealth.title=string.format('%.'..customhud.vars.precision..'f%%', health)
		local red,green=customhud.func.colorizehealth(health)
		customhud.ui.targethealth.FGCOLOR=red..' '..green..' 0 255*'
	else
		customhud.ui.targethealth.title=nil
	end
	if shields then
		shields=math.floor(tostring(shields*100))
		-- customhud.ui.targetshields.title=math.floor(shields)..'%'
		customhud.ui.targethealth.title=customhud.ui.targethealth.title..'\127ffffff:\127o\12700bde1'..shields..'%\127o'
	-- else
		-- customhud.ui.targetshields.title=nil
	end
end

function customhud.updateshiphealth()
	local d1,d2,d3,d4,d5,d6,dmg,dmgmax=GetActiveShipHealth()
	local healthpercent=''
	if dmg and dmgmax then
		healthpercent=((dmgmax-dmg)*100/dmgmax)
		customhud.ui.shiphealth.title=string.format('%.'..customhud.vars.precision..'f%%', healthpercent)
		local red,green=customhud.func.colorizehealth(healthpercent)
		customhud.ui.shiphealth.FGCOLOR=red..' '..green..' 0 255*'
	else 
		customhud.ui.shiphealth.title=nil
	end
end

function customhud.updateweaponinfo()
	for key,value in pairs(customhud.ammoweapons) do
		customhud.ui.weaponammo[key].title = GetAddonItemInfo(value)
	end
end

function customhud.commands(data,args)
	if not args then customhud.toggle()
	elseif args[1]=='config' then customhud.uiconfig.show()
	elseif args[1]=='hide' then customhud.HIDE()
	elseif args[1]=='shipinfo' then customhud.SHOWpositiondialog('shipinfo')
	elseif args[1]=='targetinfo' then customhud.SHOWpositiondialog('targetinfo')
	elseif args[1]=='weaponinfo' then customhud.SHOWpositiondialog('weaponinfo')
	elseif args[1]=='font' then 
		if tonumber(args[2]) then 
			customhud.vars.fontsize=tonumber(args[2])
			gkini.WriteString("customhud", "fontsize", tostring(args[2]))
			customhud.restart()
		else
			print('Not a valid fontsize') 
		end
	elseif args[1]=='refresh' then 
		if type(tonumber(args[2]))=='number' then
			gkini.WriteString("customhud", "refreshdelay", tonumber(args[2]))
			customhud.vars.refreshdelay=tonumber(args[2])
		else print('not a valid refresh delay')
		end
	else
		print('Wrong command.')
	end
end

function customhud.start()
	if customhud.doupdate==false then
		RegisterEvent(customhud.updateevent, 'INVENTORY_UPDATE')
		RegisterEvent(customhud.updateevent, "TARGET_HEALTH_UPDATE")
		RegisterEvent(customhud.updateevent, "SHIP_UPDATED")
		RegisterEvent(customhud.updateevent, "TARGET_CHANGED")
		
		customhud.ui.appendinfoboxes()
		customhud.SHOW()
		customhud.doupdate=true
		customhud.refresh()

		customhud.updateshiphealth()
		customhud.updatetargethealth()
		customhud.updatetargetname()
		customhud.updateweaponinfo()
	end
end

function customhud.stop()
	if customhud.doupdate==true then
		customhud.doupdate=false
		customhud.HIDE()
		customhud.ui.detachinfoboxes()
		
		UnregisterEvent(customhud.updateevent, 'INVENTORY_UPDATE')
		UnregisterEvent(customhud.updateevent, "TARGET_HEALTH_UPDATE")
		UnregisterEvent(customhud.updateevent, "SHIP_UPDATED")
		UnregisterEvent(customhud.updateevent, "TARGET_CHANGED")
	end
end

function customhud.restart()
	customhud.stop()
	customhud.start()
end

function customhud.toggle()
	if customhud.doupdate==true then customhud.stop()
	elseif customhud.doupdate==false then customhud.start()
	end
end


-- eventname=='SHIP_SPAWNED' or 
-- eventname=='LEAVING_STATION' or 
	
function customhud.event:OnEvent(eventname, args)
	if eventname=='HUD_SHOW' then
		customhud.start()
	elseif eventname=='PLAYER_LOGGED_OUT' or eventname=='ENTERING_STATION' or eventname=='HUD_HIDE' then
		customhud.stop()
	end
end

function customhud.updateevent:OnEvent(eventname, args)
	if eventname=='TARGET_HEALTH_UPDATE' then
		customhud.updatetargethealth()
	elseif eventname=='SHIP_UPDATED' then
		customhud.updateshiphealth()
	elseif eventname=='TARGET_CHANGED' then
		customhud.updatetargetname()
		customhud.updatetargethealth()
	elseif eventname=='INVENTORY_UPDATE' then
		customhud.updateweaponinfo()
	end
end



RegisterEvent(customhud.event, 'PLAYER_LOGGED_OUT')
-- RegisterEvent(customhud.event, 'LEAVING_STATION')
RegisterEvent(customhud.event, 'ENTERING_STATION')
RegisterEvent(customhud.event, 'HUD_SHOW')
RegisterEvent(customhud.event, 'HUD_HIDE')

RegisterUserCommand('togglehud', customhud.togglesomehudinfo)
RegisterUserCommand('customhud', customhud.commands)
